@@ -24,11 +24,11 @@ impl Lexer {
             captures
                 .iter() // All the captured groups
                 .skip(1) // Skipping the complete match
-                .flat_map(|c| c) // Ignoring all empty optional matches
+                .flatten() // Ignoring all empty optional matches
                 .map(|c| c.as_str()) // Grab the original strings
                 .collect::<Vec<_>>() // Create a vector
         });
-        captures.unwrap_or_else(|| Vec::new())
+        captures.unwrap_or_else(Vec::new)
     }
 }
 
@@ -92,21 +92,22 @@ impl Datum {
 pub enum Command {
     Cli(String),
     Install(i32),
-    Run(Vec<Launch>),
+    Run(i32, Vec<Launch>),
+    StartClient,
     Restart,
 }
 
 pub fn parse(block: &mut dyn Iterator<Item = &str>) -> Datum {
     let mut map = HashMap::new();
     while let Some(line) = block.next() {
-        match DATA_LEX.tokenize(&line).as_slice() {
-            &["}"] => {
+        match *DATA_LEX.tokenize(&line).as_slice() {
+            ["}"] => {
                 break;
             }
-            &[key, value] => {
+            [key, value] => {
                 map.insert(key.to_string(), Datum::Value(value.to_string()));
             }
-            &[key] => {
+            [key] => {
                 block.next();
                 map.insert(key.to_string(), parse(block));
             }
@@ -157,7 +158,6 @@ mod tests {
             .maybe_nest()
             .expect("Failed to properly parse");
         assert_eq!(inner.len(), 0);
-        eprintln!("{:?}", map);
         let complex = map
             .get(&"otherØ 天 🎉".to_string())
             .unwrap()
